An Extraordinary Paradise Valley Residence : Architectural Digest
Author: Architectural Digest
Description: Architect Marwan Al-Sayed and designer Jan Showers craft a majestic modern sanctuary in the Arizona desert
Keywords: January 2015, Decorating Tout, Decor, Interiors, Decor Tout, AD100, Jan Showers, Homes Rotator

Close
Close

##

##

# An Extraordinary Paradise Valley Residence

## Architect Marwan Al-Sayed and designer Jan Showers craft a majestic modern sanctuary in the Arizona desert

Text by Mayer Rus | Photography by Scott Frances | Produced by Howard Christian

View Slideshow

Print
Homeowners Joann and Paul Delaney.

Not very often does one hear a contemporary architect allude to the mortuary temple of the Egyptian pharaoh Hatshepsut when describing the inspiration for a new house. Ditto the rather obscure Majorcan cliff-top villa Can Lis, designed by Sydney Opera House mastermind Jørn Utzon. But in the context of the extraordinary Arizona residence that architect Marwan Al-Sayed and decorator Jan Showers created for Joann and Paul Delaney, these seemingly arcane reference points actually make perfect sense. In addition to its similar setting (sunbaked rocky landscape), building material (stone), and overall form (rectilinear), the retreat shares another, less tangible quality with those unexpected antecedents—timeless, otherworldly serenity.

"I remember Paul telling me that he wanted the house to last a thousand years," says Al-Sayed, a recent Phoenix-to–Los Angeles transplant who was part of the design triumvirate responsible for the astonishing Amangiri resort in Utah. "So I was intrigued by the idea of ancient architecture—its weight, proportion, grandeur, and materiality."

The 9,000-square-foot, single-level dwelling he ultimately devised sits on nine acres of desert terrain at the foot of Mummy Mountain (did someone say Egypt?) in the aptly named Phoenix suburb of Paradise Valley, a place where rugged red hills cast craggy shadows across a landscape of saguaro cacti, aloe vera plants, and creosote bushes. Approaching the house from the front drive, one is greeted by a poker-faced exterior of limestone blocks. With little hint of what lies beyond, the elevation might easily be mistaken for the façade of a formulaic modernist box.

Any such notions quickly vanish, however, as the entry procession leads through a semienclosed passageway directly into a glorious courtyard. Straight ahead lie the main entertaining areas—the living and dining rooms as well as an art-lined gallery—but visitors are meant to pause in this oasis-like reception space, planted with mesquite trees and highlighted by what seems to be a vast reflecting pool. Framed in black granite, the water feature is, in fact, a ten-foot-deep infinity swimming pool that cascades over its far wall into a shallow basin below.

Flanking the pool are two loggias—one off the master suite and the other off the guest quarters—delineated by limestone brise-soleils that orchestrate an ever-changing dance of reflected light. "I used limestone for both the courtyard floor and most of the walls to underscore the idea of the house as a configuration of interconnected pavilions with varying degrees of exposure," the architect says, noting the stone's luminous yet earthy quality. "Using one material throughout has a calming effect—it gives you the luxury of tuning out the cacophony of the outside world."

For the full story and more photos, subscribe now and get the digital edition immediately.

Tour Joann and Paul Delaney's sleek home.

prev

next
Print

##

## AROUND THE WEB

Best of AD in Your Inbox

Sign up now

Get the latest in design, decorating, celebrity style, shopping, and more

Subscribe
Connect With Us

This is not a valid e-mail address

##

## MOST POPULAR

###

##

## AROUND THE WEB

ADVERTISEMENT

##

## AROUND THE WEB

##

## More Stories